==> open_swarm-0.1.1744936380.tar.gz: open_swarm-0.1.1744936380/tests/blueprints/test_gotchaman.py <==
import pytest
from unittest.mock import patch, AsyncMock, MagicMock

# Assuming BlueprintBase and other necessary components are importable
# from blueprints.gotchaman.blueprint_gotchaman import GotchamanBlueprint
# from agents import Agent, Runner, RunResult, MCPServer

@pytest.fixture
def gotchaman_blueprint_instance():
    """Fixture to create a mocked instance of GotchamanBlueprint."""
    with patch('blueprints.gotchaman.blueprint_gotchaman.BlueprintBase._load_configuration', return_value={'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}):
         with patch('blueprints.gotchaman.blueprint_gotchaman.BlueprintBase._get_model_instance') as mock_get_model:
             mock_model_instance = MagicMock()
             mock_get_model.return_value = mock_model_instance
             from blueprints.gotchaman.blueprint_gotchaman import GotchamanBlueprint
             instance = GotchamanBlueprint(debug=True)
    return instance

# --- Test Cases ---

@pytest.mark.skip(reason="Blueprint tests not yet implemented")
def test_gotchaman_agent_creation(gotchaman_blueprint_instance):
    """Test if Ken and the team agents are created correctly."""
    # Arrange
    blueprint = gotchaman_blueprint_instance
    mock_mcps = [
        MagicMock(spec=MCPServer, name="slack"),
        MagicMock(spec=MCPServer, name="mondayDotCom"), # Config might vary
        MagicMock(spec=MCPServer, name="basic-memory"),
        MagicMock(spec=MCPServer, name="mcp-npx-fetch"),
    ]
    # Act
    starting_agent = blueprint.create_starting_agent(mcp_servers=mock_mcps)
    # Assert
    assert starting_agent is not None
    assert starting_agent.name == "Ken"
    tool_names = {t.name for t in starting_agent.tools}
    assert tool_names == {"Joe", "Jun", "Jinpei", "Ryu"}
    # Further checks: Find Joe via tools, check his function tools etc.

@pytest.mark.skip(reason="Tool function tests not yet implemented")
@patch('blueprints.gotchaman.blueprint_gotchaman.subprocess.run')
def test_gotchaman_execute_command_tool(mock_subprocess_run):
    """Test the execute_command tool function directly."""
    from blueprints.gotchaman.blueprint_gotchaman import execute_command
    # Arrange
    mock_result = MagicMock()
    mock_result.stdout = "Command output here"
    mock_result.stderr = ""
    mock_result.returncode = 0
    mock_subprocess_run.return_value = mock_result
    # Act
    result = execute_command(command="ls -l")
    # Assert
    mock_subprocess_run.assert_called_once_with(
        "ls -l", shell=True, check=False, capture_output=True, text=True, timeout=120
    )
    assert "OK: Command executed" in result
    assert "Command output here" in result

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_gotchaman_delegation_flow(gotchaman_blueprint_instance):
    """Test a delegation flow, e.g., Ken -> Joe -> execute_command."""
    # Needs Runner mocking, potentially subprocess mocking for Joe's tool.
    assert False

@pytest.mark.skip(reason="Blueprint CLI tests not yet implemented")
def test_gotchaman_cli_execution():
    """Test running the blueprint via CLI."""
    assert False

==> open_swarm-0.1.1745274515.tar.gz: open_swarm-0.1.1745274515/tests/blueprints/test_gotchaman.py <==
import pytest
from unittest.mock import patch, AsyncMock, MagicMock

# Assuming BlueprintBase and other necessary components are importable
# from blueprints.gotchaman.blueprint_gotchaman import GotchamanBlueprint
# from agents import Agent, Runner, RunResult, MCPServer

@pytest.fixture
def gotchaman_blueprint_instance():
    with patch('swarm.core.blueprint_base.BlueprintBase._load_and_process_config', return_value={'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}):
        with patch('swarm.core.blueprint_base.BlueprintBase._get_model_instance') as mock_get_model:
            mock_model_instance = MagicMock()
            mock_get_model.return_value = mock_model_instance
            from swarm.blueprints.gotchaman.blueprint_gotchaman import GotchamanBlueprint
            instance = GotchamanBlueprint(blueprint_id="test_gotchaman", debug=True)
            instance._config = {'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}
            instance.mcp_server_configs = {}
            return instance

# --- Test Cases ---

@pytest.mark.skip(reason="Implementation for GotchamanBlueprint not found in codebase; skipping test.")
def test_gotchaman_agent_creation():
    pass

@pytest.mark.skip(reason="Tool function tests not yet implemented")
@patch('blueprints.gotchaman.blueprint_gotchaman.subprocess.run')
def test_gotchaman_execute_command_tool(mock_subprocess_run):
    """Test the execute_command tool function directly."""
    from blueprints.gotchaman.blueprint_gotchaman import execute_command
    # Arrange
    mock_result = MagicMock()
    mock_result.stdout = "Command output here"
    mock_result.stderr = ""
    mock_result.returncode = 0
    mock_subprocess_run.return_value = mock_result
    # Act
    result = execute_command(command="ls -l")
    # Assert
    mock_subprocess_run.assert_called_once_with(
        "ls -l", shell=True, check=False, capture_output=True, text=True, timeout=120
    )
    assert "OK: Command executed" in result
    assert "Command output here" in result

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_gotchaman_delegation_flow(gotchaman_blueprint_instance):
    """Test a delegation flow, e.g., Ken -> Joe -> execute_command."""
    # Needs Runner mocking, potentially subprocess mocking for Joe's tool.
    assert False

@pytest.mark.skip(reason="Blueprint CLI tests not yet implemented")
def test_gotchaman_cli_execution():
    """Test running the blueprint via CLI."""
    assert False
